# Swagger\Client\EFTCreditBatchesApi

Method | HTTP request | Description
------------- | ------------- | -------------
[**creditSubmitBatch**](EFTCreditBatchesApi.md#creditsubmitbatch) | **POST** /batch/credit/{id}/submit | Submit a EFT Credit batch to Bankserv.
[**creditUploadCsv**](EFTCreditBatchesApi.md#credituploadcsv) | **POST** /batch/credit | Upload a CSV batch file containing the credit transactions to submit to Bankserv.
[**creditUploadJson**](EFTCreditBatchesApi.md#credituploadjson) | **POST** /batch/credit/json | Upload JSON transactions to submit to Bankserv.


# creditSubmitBatch
> \Swagger\Client\Model\BatchSubmitResponse creditSubmitBatch($id, $service_type)

Submit a EFT Credit batch to Bankserv.

Manually submit a EFT Credit batch to Bankserv for processing.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure HTTP basic authorization: basic
Swagger\Client\Configuration::getDefaultConfiguration()->setUsername('YOUR_INSTALLATION_CODE');
Swagger\Client\Configuration::getDefaultConfiguration()->setPassword('YOUR_API_PASSWORD');
Swagger\Client\Configuration::getDefaultConfiguration()->setHost('https://dos-dr.directdebit.co.za:31143/v1');

$api_instance = new Swagger\Client\Api\EFTCreditBatchesApi();
$id = 56; // int | Batch `id` that needs to be submitted to live system.
$service_type = "service_type_example"; // string | Service type can be either `sameday` or `oneday`.

try {
    $result = $api_instance->creditSubmitBatch($id, $service_type);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling EFTCreditBatchesApi->creditSubmitBatch: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **int**| Batch &#x60;id&#x60; that needs to be submitted to live system. |
 **service_type** | **string**| Service type can be either &#x60;sameday&#x60; or &#x60;oneday&#x60;. | [optional]

### Return type

[**\Swagger\Client\Model\BatchSubmitResponse**](../Model/BatchSubmitResponse.md)

### Authorization

[basic](../../README.md#basic)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<div class="text-center">
<span class="well well-sm">
[Top](#) | [API list](../../README.md#documentation-for-api-endpoints) | [Model list](../../README.md#documentation-for-models) | [Index](../../README.md)
</span>
</div>


# creditUploadCsv
> \Swagger\Client\Model\BatchChecksum creditUploadCsv($file_data, $service_type, $action_date, $skip_cdv_check, $skip_checksum, $submit_to_bank)

Upload a CSV batch file containing the credit transactions to submit to Bankserv.

Upload a correctly formatted CSV batch file ([download example here](https://dos.directdebit.co.za:31143/static/resources/directdebit-example-eft-batch.csv)). The file will be  validated after returning an `id` and MD5 `checksum`. You can use the `id` to check the progress of validation and `checksum` to validate the integrity of the posted batch file.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure HTTP basic authorization: basic
Swagger\Client\Configuration::getDefaultConfiguration()->setUsername('YOUR_INSTALLATION_CODE');
Swagger\Client\Configuration::getDefaultConfiguration()->setPassword('YOUR_API_PASSWORD');
Swagger\Client\Configuration::getDefaultConfiguration()->setHost('https://dos-dr.directdebit.co.za:31143/v1');

$api_instance = new Swagger\Client\Api\EFTCreditBatchesApi();
$file_data = "/path/to/file.txt"; // \SplFileObject | Upload a correctly formatted CSV file ([download example here](https://dos.directdebit.co.za:31143/static/resources/directdebit-example-eft-batch.csv)) to submit to Bankserv.
$service_type = "service_type_example"; // string | Service type can be either `sameday` or `oneday`.
$action_date = "action_date_example"; // string | Action date `yyyy-mm-dd` (date on which the payment becomes effective).
$skip_cdv_check = true; // bool | Skip CDV verification (Check Digit Verification).
$skip_checksum = true; // bool | Skip checking of duplicate batch files.
$submit_to_bank = true; // bool | Set to `true` in order to submit transactions automatically to Bankserv. **ONLY VALID** transactions (if `skip_cdv_check = false`) and **ALL** transactions (if `skip_cdv_check = true`).

try {
    $result = $api_instance->creditUploadCsv($file_data, $service_type, $action_date, $skip_cdv_check, $skip_checksum, $submit_to_bank);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling EFTCreditBatchesApi->creditUploadCsv: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **file_data** | **\SplFileObject**| Upload a correctly formatted CSV file ([download example here](https://dos.directdebit.co.za:31143/static/resources/directdebit-example-eft-batch.csv)) to submit to Bankserv. |
 **service_type** | **string**| Service type can be either &#x60;sameday&#x60; or &#x60;oneday&#x60;. | [optional]
 **action_date** | **string**| Action date &#x60;yyyy-mm-dd&#x60; (date on which the payment becomes effective). | [optional]
 **skip_cdv_check** | **bool**| Skip CDV verification (Check Digit Verification). | [optional]
 **skip_checksum** | **bool**| Skip checking of duplicate batch files. | [optional]
 **submit_to_bank** | **bool**| Set to &#x60;true&#x60; in order to submit transactions automatically to Bankserv. **ONLY VALID** transactions (if &#x60;skip_cdv_check &#x3D; false&#x60;) and **ALL** transactions (if &#x60;skip_cdv_check &#x3D; true&#x60;). | [optional]

### Return type

[**\Swagger\Client\Model\BatchChecksum**](../Model/BatchChecksum.md)

### Authorization

[basic](../../README.md#basic)

### HTTP request headers

 - **Content-Type**: multipart/form-data
 - **Accept**: application/json

<div class="text-center">
<span class="well well-sm">
[Top](#) | [API list](../../README.md#documentation-for-api-endpoints) | [Model list](../../README.md#documentation-for-models) | [Index](../../README.md)
</span>
</div>


# creditUploadJson
> \Swagger\Client\Model\BatchCount creditUploadJson($transactions, $service_type, $action_date, $skip_cdv_check, $submit_to_bank)

Upload JSON transactions to submit to Bankserv.

Upload an array of JSON transactions you want to submit to Bankserv.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure HTTP basic authorization: basic
Swagger\Client\Configuration::getDefaultConfiguration()->setUsername('YOUR_INSTALLATION_CODE');
Swagger\Client\Configuration::getDefaultConfiguration()->setPassword('YOUR_API_PASSWORD');
Swagger\Client\Configuration::getDefaultConfiguration()->setHost('https://dos-dr.directdebit.co.za:31143/v1');

$api_instance = new Swagger\Client\Api\EFTCreditBatchesApi();
$transactions = array(new BatchTransaction()); // \Swagger\Client\Model\BatchTransaction[] | JSON transactions to be uploaded.
$service_type = "service_type_example"; // string | Service type can be either `sameday` or `oneday`.
$action_date = "action_date_example"; // string | Action date `yyyy-mm-dd` (date on which the payment becomes effective).
$skip_cdv_check = true; // bool | Skip CDV verification (Check Digit Verification).
$submit_to_bank = true; // bool | Set to `true` in order to submit transactions automatically to Bankserv. **ONLY VALID** transactions (if `skip_cdv_check = false`) and **ALL** transactions (if `skip_cdv_check = true`).

try {
    $result = $api_instance->creditUploadJson($transactions, $service_type, $action_date, $skip_cdv_check, $submit_to_bank);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling EFTCreditBatchesApi->creditUploadJson: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **transactions** | [**\Swagger\Client\Model\BatchTransaction[]**](../Model/BatchTransaction.md)| JSON transactions to be uploaded. |
 **service_type** | **string**| Service type can be either &#x60;sameday&#x60; or &#x60;oneday&#x60;. | [optional]
 **action_date** | **string**| Action date &#x60;yyyy-mm-dd&#x60; (date on which the payment becomes effective). | [optional]
 **skip_cdv_check** | **bool**| Skip CDV verification (Check Digit Verification). | [optional]
 **submit_to_bank** | **bool**| Set to &#x60;true&#x60; in order to submit transactions automatically to Bankserv. **ONLY VALID** transactions (if &#x60;skip_cdv_check &#x3D; false&#x60;) and **ALL** transactions (if &#x60;skip_cdv_check &#x3D; true&#x60;). | [optional]

### Return type

[**\Swagger\Client\Model\BatchCount**](../Model/BatchCount.md)

### Authorization

[basic](../../README.md#basic)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

<div class="text-center">
<span class="well well-sm">
[Top](#) | [API list](../../README.md#documentation-for-api-endpoints) | [Model list](../../README.md#documentation-for-models) | [Index](../../README.md)
</span>
</div>


