# Swagger\Client\ReconApi

Method | HTTP request | Description
------------- | ------------- | -------------
[**getRecon**](ReconApi.md#getrecon) | **GET** /recon | Retrieve reconciliation of transactions processed.
[**putReinstate**](ReconApi.md#putreinstate) | **PUT** /recon/reinstate | Reinstate a suspended account.


# getRecon
> \Swagger\Client\Model\ReconTransaction[] getRecon($id, $from_action_date, $to_action_date, $from_recon_date, $to_recon_date, $state, $state_code, $state_reason, $nominated_account, $queue)

Retrieve reconciliation of transactions processed.

Retrieve reconciliation of transactions processed. Parameters to filter the result set will need to be supplied. If larger datasets are used, the `queue` parameter will need to be utilised (available on request).

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure HTTP basic authorization: basic
Swagger\Client\Configuration::getDefaultConfiguration()->setUsername('YOUR_INSTALLATION_CODE');
Swagger\Client\Configuration::getDefaultConfiguration()->setPassword('YOUR_API_PASSWORD');
Swagger\Client\Configuration::getDefaultConfiguration()->setHost('https://dos-dr.directdebit.co.za:31143/v1');

$api_instance = new Swagger\Client\Api\ReconApi();
$id = 56; // int | Recon a specific batch `id` only.
$from_action_date = "from_action_date_example"; // string | Search recon from date \"yyyy-mm-dd\" (action date).
$to_action_date = "to_action_date_example"; // string | Search recon to date \"yyyy-mm-dd\"(action date).
$from_recon_date = "from_recon_date_example"; // string | Search recon from date \"yyyy-mm-dd\" (recon date).
$to_recon_date = "to_recon_date_example"; // string | Search recon to date \"yyyy-mm-dd\" (recon date).
$state = "state_example"; // string | System only returns transactions with a specific state.
$state_code = "state_code_example"; // string | System only returns transactions with a specific state code.
$state_reason = "state_reason_example"; // string | System only returns transactions with a specific state reason.
$nominated_account = "nominated_account_example"; // string | Nominated account provided in your initial service type settings.
$queue = true; // bool | Send the recon response to a queue instead of in the response body. Listen on the queue `topic` returned.

try {
    $result = $api_instance->getRecon($id, $from_action_date, $to_action_date, $from_recon_date, $to_recon_date, $state, $state_code, $state_reason, $nominated_account, $queue);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling ReconApi->getRecon: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **int**| Recon a specific batch &#x60;id&#x60; only. | [optional]
 **from_action_date** | **string**| Search recon from date \&quot;yyyy-mm-dd\&quot; (action date). | [optional]
 **to_action_date** | **string**| Search recon to date \&quot;yyyy-mm-dd\&quot;(action date). | [optional]
 **from_recon_date** | **string**| Search recon from date \&quot;yyyy-mm-dd\&quot; (recon date). | [optional]
 **to_recon_date** | **string**| Search recon to date \&quot;yyyy-mm-dd\&quot; (recon date). | [optional]
 **state** | **string**| System only returns transactions with a specific state. | [optional]
 **state_code** | **string**| System only returns transactions with a specific state code. | [optional]
 **state_reason** | **string**| System only returns transactions with a specific state reason. | [optional]
 **nominated_account** | **string**| Nominated account provided in your initial service type settings. | [optional]
 **queue** | **bool**| Send the recon response to a queue instead of in the response body. Listen on the queue &#x60;topic&#x60; returned. | [optional]

### Return type

[**\Swagger\Client\Model\ReconTransaction[]**](../Model/ReconTransaction.md)

### Authorization

[basic](../../README.md#basic)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<div class="text-center">
<span class="well well-sm">
[Top](#) | [API list](../../README.md#documentation-for-api-endpoints) | [Model list](../../README.md#documentation-for-models) | [Index](../../README.md)
</span>
</div>


# putReinstate
> object putReinstate($reference, $reinstated)

Reinstate a suspended account.

Reinstate a suspended account using the client reference. Suspended accounts include disputed transactions as well as transactions that have returned unpaid for two (2) consecutive months.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure HTTP basic authorization: basic
Swagger\Client\Configuration::getDefaultConfiguration()->setUsername('YOUR_INSTALLATION_CODE');
Swagger\Client\Configuration::getDefaultConfiguration()->setPassword('YOUR_API_PASSWORD');
Swagger\Client\Configuration::getDefaultConfiguration()->setHost('https://dos-dr.directdebit.co.za:31143/v1');

$api_instance = new Swagger\Client\Api\ReconApi();
$reference = "reference_example"; // string | The client reference (user reference as specified on mandate).
$reinstated = true; // bool | This is set by default as `true`. You can cancel the reinstatement by setting this to `false`.

try {
    $result = $api_instance->putReinstate($reference, $reinstated);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling ReconApi->putReinstate: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **reference** | **string**| The client reference (user reference as specified on mandate). | [optional]
 **reinstated** | **bool**| This is set by default as &#x60;true&#x60;. You can cancel the reinstatement by setting this to &#x60;false&#x60;. | [optional]

### Return type

**object**

### Authorization

[basic](../../README.md#basic)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<div class="text-center">
<span class="well well-sm">
[Top](#) | [API list](../../README.md#documentation-for-api-endpoints) | [Model list](../../README.md#documentation-for-models) | [Index](../../README.md)
</span>
</div>


